"use strict";(self.webpackChunkjupyter_leaflet=self.webpackChunkjupyter_leaflet||[]).push([[35],{1035:(t,e,n)=>{n.r(e),n.d(e,{Spinner:()=>s});var i=function(){return i=Object.assign||function(t){for(var e,n=1,i=arguments.length;n<i;n++)for(var r in e=arguments[n])Object.prototype.hasOwnProperty.call(e,r)&&(t[r]=e[r]);return t},i.apply(this,arguments)},r={lines:12,length:7,width:5,radius:10,scale:1,corners:1,color:"#000",fadeColor:"transparent",animation:"spinner-line-fade-default",rotate:0,direction:1,speed:1,zIndex:2e9,className:"spinner",top:"50%",left:"50%",shadow:"0 0 1px transparent",position:"absolute"},s=function(){function t(t){void 0===t&&(t={}),this.opts=i(i({},r),t)}return t.prototype.spin=function(t){return this.stop(),this.el=document.createElement("div"),this.el.className=this.opts.className,this.el.setAttribute("role","progressbar"),o(this.el,{position:this.opts.position,width:0,zIndex:this.opts.zIndex,left:this.opts.left,top:this.opts.top,transform:"scale("+this.opts.scale+")"}),t&&t.insertBefore(this.el,t.firstChild||null),function(t,e){var n=Math.round(e.corners*e.width*500)/1e3+"px",i="none";!0===e.shadow?i="0 2px 4px #000":"string"==typeof e.shadow&&(i=e.shadow);for(var r=function(t){for(var e=/^\s*([a-zA-Z]+\s+)?(-?\d+(\.\d+)?)([a-zA-Z]*)\s+(-?\d+(\.\d+)?)([a-zA-Z]*)(.*)$/,n=[],i=0,r=t.split(",");i<r.length;i++){var s=r[i].match(e);if(null!==s){var o=+s[2],a=+s[5],l=s[4],d=s[7];0!==o||l||(l=d),0!==a||d||(d=l),l===d&&n.push({prefix:s[1]||"",x:o,y:a,xUnits:l,yUnits:d,end:s[8]})}}return n}(i),s=0;s<e.lines;s++){var d=~~(360/e.lines*s+e.rotate),h=o(document.createElement("div"),{position:"absolute",top:-e.width/2+"px",width:e.length+e.width+"px",height:e.width+"px",background:a(e.fadeColor,s),borderRadius:n,transformOrigin:"left",transform:"rotate("+d+"deg) translateX("+e.radius+"px)"}),p=s*e.direction/e.lines/e.speed;p-=1/e.speed;var u=o(document.createElement("div"),{width:"100%",height:"100%",background:a(e.color,s),borderRadius:n,boxShadow:l(r,d),animation:1/e.speed+"s linear "+p+"s infinite "+e.animation});h.appendChild(u),t.appendChild(h)}}(this.el,this.opts),this},t.prototype.stop=function(){return this.el&&("undefined"!=typeof requestAnimationFrame?cancelAnimationFrame(this.animateId):clearTimeout(this.animateId),this.el.parentNode&&this.el.parentNode.removeChild(this.el),this.el=void 0),this},t}();function o(t,e){for(var n in e)t.style[n]=e[n];return t}function a(t,e){return"string"==typeof t?t:t[e%t.length]}function l(t,e){for(var n=[],i=0,r=t;i<r.length;i++){var s=r[i],o=d(s.x,s.y,e);n.push(s.prefix+o[0]+s.xUnits+" "+o[1]+s.yUnits+s.end)}return n.join(", ")}function d(t,e,n){var i=n*Math.PI/180,r=Math.sin(i),s=Math.cos(i);return[Math.round(1e3*(t*s+e*r))/1e3,Math.round(1e3*(-t*r+e*s))/1e3]}}}]);