(self.webpackChunkjupyter_leaflet=self.webpackChunkjupyter_leaflet||[]).push([[738],{3738:(e,t,r)=>{var a=r(8138),s=r(1395);e.exports={id:"jupyter.extensions.jupyter-leaflet",requires:[s.IJupyterWidgetRegistry],activate:function(e,t){t.registerWidget({name:"jupyter-leaflet",version:a.version,exports:a})},autoStart:!0}}}]);